@@ -24,6 +24,7 @@ from .common import pack_pingresp
 from .common import pack_disconnect
 from .common import unpack_disconnect
 from .common import format_packet
+from .common import format_packet_compact
 from .common import CF_FIXED_HEADER
 from .common import MAXIMUM_PACKET_SIZE
 
@@ -177,6 +178,8 @@ class Client(object):
         if LOGGER.isEnabledFor(logging.DEBUG):
             for line in format_packet('Received', buf + data):
                 self.log_debug(line)
+        elif LOGGER.isEnabledFor(logging.INFO):
+            self.log_info(format_packet_compact('Received', buf + data))
 
         return packet_type, flags, PayloadReader(data)
 
@@ -316,15 +319,19 @@ class Client(object):
     def disconnect(self):
         self._write_packet(pack_disconnect(self._disconnect_reason))
 
+    def _send_prefix(self, message):
+        if len(message) <= self._session.maximum_packet_size:
+            return 'Sending'
+        else:
+            return 'Not sending'
+
     def _write_packet(self, message):
         if LOGGER.isEnabledFor(logging.DEBUG):
-            if len(message) <= self._session.maximum_packet_size:
-                prefix = 'Sending'
-            else:
-                prefix = 'Not sending'
-
-            for line in format_packet(prefix, message):
+            for line in format_packet(self._send_prefix(message), message):
                 self.log_debug(line)
+        elif LOGGER.isEnabledFor(logging.INFO):
+            self.log_info(format_packet_compact(self._send_prefix(message),
+                                                message))
 
         if len(message) <= self._session.maximum_packet_size:
             self._writer.write(message)
@@ -356,6 +363,11 @@ class Broker(object):
     `secure_ssl` is an SSL context passed to `asyncio.start_server()`
     as `ssl`.
 
+    Create a broker and serve clients:
+
+    >>> broker = Broker('broker.hivemq.com')
+    >>> await broker.serve_forever()
+
     """
 
     def __init__(self, host, port=1883, secure_port=8883, secure_ssl=None):
@@ -537,38 +549,34 @@ class Broker(object):
 
 
 class BrokerThread(threading.Thread):
-    """A limited MQTT version 5.0 broker running in a thread.
+    """The same as :class:`Broker`, but running in a thread.
 
-    `host`, `port` and `secure_port` are the host and ports to listen
-    for clients on.
+    Create a broker and serve clients for 60 seconds:
 
-    `secure_ssl` is an SSL context passed to `asyncio.start_server()`
-    as `ssl`.
+    >>> broker = BrokerThread('broker.hivemq.com')
+    >>> broker.start()
+    >>> time.sleep(60)
+    >>> broker.stop()
 
     """
 
-    def __init__(self, host, port=1883, secure_port=8883, secure_ssl=None):
+    def __init__(self, *args, **kwargs):
         super().__init__()
-        self._host = host
-        self._port = port
-        self._secure_port = secure_port
-        self._secure_ssl = secure_ssl
+        self._args = args
+        self._kwargs = kwargs
         self.daemon = True
-        self._loop = None
-        self._broker = None
-        self._broker_task = None
+        self._loop = asyncio.new_event_loop()
+        self._broker_task = self._loop.create_task(self._run())
         self._running = False
 
     def run(self):
-        self.loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(self.loop)
-        self.broker_task = self.loop.create_task(self._run())
+        asyncio.set_event_loop(self._loop)
         self._running = True
 
         try:
-            self.loop.run_until_complete(self.broker_task)
+            self._loop.run_until_complete(self._broker_task)
         finally:
-            self.loop.close()
+            self._loop.close()
 
     def stop(self):
         """Stop the broker. All clients will be disconnected and the thread
@@ -582,18 +590,15 @@ class BrokerThread(threading.Thread):
         self._running = False
 
         def cancel_broker_task():
-            self.broker_task.cancel()
+            self._broker_task.cancel()
 
-        self.loop.call_soon_threadsafe(cancel_broker_task)
+        self._loop.call_soon_threadsafe(cancel_broker_task)
         self.join()
 
     async def _run(self):
-        self._broker = Broker(self._host,
-                              self._port,
-                              self._secure_port,
-                              self._secure_ssl)
+        broker = Broker(*self._args, **self._kwargs)
 
         try:
-            await self._broker.serve_forever()
+            await broker.serve_forever()
         except asyncio.CancelledError:
-            self._broker = None
+            pass
